# -*- coding: utf-8 -*-
"""
Created on Sun Sep  4 21:02:13 2022

@author: Dina
"""
import pandas as pd

from sklearn.preprocessing import RobustScaler
from sklearn.ensemble import RandomForestClassifier
from sklearn import metrics
from sklearn.tree import DecisionTreeClassifier
# from matplotlib.pyplot import figure

#%%
dataset = pd.read_csv('Appendix S1.csv')

#%%
from sklearn.model_selection import train_test_split

input_elements = ['P, ppm', 'Ti, ppm',
       'Y, ppm', 'Nb, ppm', 'Ba, ppm', 'La, ppm', 'Ce, ppm', 'Nd, ppm',
       'Sm, ppm', 'Eu, ppm', 'Gd, ppm', 'Tb, ppm', 'Dy, ppm', 'Ho, ppm',
       'Er, ppm', 'Tm, ppm', 'Yb, ppm', 'Lu, ppm', 'Hf, ppm', 'Pb, ppm',
       'Th, ppm', 'U, ppm', 'Eu*', 'Ce*']
output_deposits = ['Deposit']
X = dataset[input_elements]

#%%
# Scale the data

##
scaler = RobustScaler().fit(X)
X = pd.DataFrame(scaler.transform(X))
y = dataset.Deposit
X.describe() 
X_train, X_test, y_train, y_test=train_test_split(X, y, test_size=0.3, stratify=y)

#%%

dtmodel=DecisionTreeClassifier()
dtmodel.fit(X_train,y_train)

#%%

# use GridSearch for parameter tuning

from sklearn.model_selection import GridSearchCV
n_estimators = [50,100,200,500,1000]
max_depth = [3,5,10,15,20,None]
##
parameters = {'n_estimators':n_estimators, 'max_depth':max_depth}
classifier = RandomForestClassifier(random_state=27)
model = GridSearchCV(estimator=classifier,param_grid=parameters,cv=10,n_jobs=-1)
model.fit(X_train,y_train)

# best parameters: {'max_depth': 15, 'n_estimators': 100}


#%%
# predict: Random forest
rf_classifier = RandomForestClassifier(random_state=27, max_depth=15, n_estimators=100) 
rf_classifier.fit(X_train, y_train)

#%%
# accuracy metric

rf_predict = rf_classifier.predict(X_test)
rf_accuracy=metrics.accuracy_score(rf_predict,y_test)
print(rf_accuracy * 100)

#%% 

# parameter tuning for decision tree classifier
criterion = ['gini', 'entropy', 'log_loss']
max_depth = [3,5,10,15,20,None]
##
parameters = {'criterion':criterion, 'max_depth':max_depth}
classifier = DecisionTreeClassifier(random_state=27)
model = GridSearchCV(estimator=classifier,param_grid=parameters,cv=10,n_jobs=-1)
model.fit(X_train,y_train)

# best parameters: {'criterion': 'gini', 'max_depth': 5}
#%%
# train with tuned parameters
dt_classifier = DecisionTreeClassifier(random_state=27, max_depth=5, criterion='gini') 
dt_classifier.fit(X_train, y_train)

#%%
# accuracy metric

dt_predict = dt_classifier.predict(X_test)
dt_accuracy=metrics.accuracy_score(dt_predict,y_test)
print(dt_accuracy * 100)
